==> nextcloud-28.0.7.tgz: nextcloud/apps/survey_client/l10n/gl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último informe enviado o: {on}",
    "An error occurred while sending your report." : "Produciuse un erro ao enviar o seu informe.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicacións <em>(para cada aplicación: nome, versión, estado da activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Contorno da base de datos <em>(tipo, versión, tamaño da base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información do cifrado <em>(está activado?, cal é o módulo predeterminado)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de comparticións <em>(por tipo e configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Contorno PHP PHP<em>(versión, límite de memoria, tempo máx. de execución, tamaño máximo de ficheiro)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles da instancia do servidor <em>(versión, uso de memcache, estado do bloqueo de ficheiros/vistas previas/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de ficheiros, usuarios, almacenamentos por tipo, comentarios e etiquetas)",
    "Usage survey" : "Enquisa de uso",
    "Help improve Nextcloud" : "Axude a mellorar Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Quere colabore connosco para mellorar Nextcloud achegando algúns datos anónimos sobre os seus axustes e uso? Pode desactivalo en calquera momento nos axustes de administración.",
    "Not now" : "Agora non",
    "Send usage" : "Enviar o uso",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar NextCloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar NextCloud\n\t\tVde. terá sempre o control total do contido enviado a Nextcloud e poderá\n\t\tdesactivalo en calquera momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Pode axudar a mellorar Nextcloud enviándonos algúns datos sobre os seus axustes e e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Tomámonos moi en serio a súa privacidade. O envío de datos, por omisión, está desactivado, e se o activa, o primeiro será anonimizalos e daráselle a opción de escoller que é o que quere compartir. Ao recibir un informe, retirarase o anterior. Envíe un informe en branco para eliminar todos os datos almacenados actualmente no servidor.",
    "Send new report now" : "Enviar agora un novo informe",
    "Send usage survey monthly" : "Enviar a enquisa de uso mensualmente",
    "Data to send" : "Data do envío",
    "Last report sent on: %s" : "O último informe foi enviado o: %s",
    "Last report" : "Último informe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/survey_client/l10n/gl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Último informe enviado o: {on}",
    "An error occurred while sending your report." : "Produciuse un erro ao enviar o seu informe.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista de aplicacións <em>(para cada aplicación: nome, versión, estado da activación)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Contorno da base de datos <em>(tipo, versión, tamaño da base de datos)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Información da cifraxe <em>(está activada?, cal é o módulo predeterminado)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Número de comparticións <em>(por tipo e configuración de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Contorno PHP PHP<em>(versión, límite de memoria, tempo máx. de execución, tamaño máximo de ficheiro)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalles da instancia do servidor <em>(versión, uso de memcache, estado do bloqueo de ficheiros/vistas previas/avatares)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estatísticas <em>(número de ficheiros, usuarios, almacenamentos por tipo, comentarios e etiquetas)",
    "Usage survey" : "Enquisa de uso",
    "Help improve Nextcloud" : "Axude a mellorar Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Quere colaborar connosco para mellorar Nextcloud achegando algúns datos anónimos sobre os seus axustes e uso? Pode desactivalo en calquera momento nos axustes de administración.",
    "Send usage" : "Enviar o uso",
    "Not now" : "Agora non",
    "Never" : "Nunca",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar NextCloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar NextCloud\n\t\tVde. terá sempre o control total do contido enviado a Nextcloud e poderá\n\t\tdesactivalo en calquera momento.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Pode axudar a mellorar Nextcloud enviándonos algúns datos sobre os seus axustes e e uso.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. To delete the stored usage data, upload an empty report by unchecking all of the boxes then sending a new report." : "Tomámonos moi en serio a súa privacidade. O envío de datos, por omisión, está desactivado, e se o activa, o primeiro será anonimizalos e daráselle a opción de escoller que é o que quere compartir. Ao recibir un informe, retirarase o anterior. Para eliminar os datos de uso almacenados, envíe un informe baleiro desmarcando todas as caixas e envíe un novo informe.",
    "Send new report now" : "Enviar agora un novo informe",
    "Send usage survey monthly" : "Enviar a enquisa de uso mensualmente",
    "Data to send" : "Data do envío",
    "Last report sent on: %s" : "O último informe foi enviado o: %s",
    "Last report" : "Último informe"
},
"nplurals=2; plural=(n != 1);");
